from datetime import datetime
from flask import current_app, flash, redirect, render_template, url_for
from flask_login import current_user, login_required
from ..models import User
from ..tables import AdminUserTable, AdminUserItem
from . import main
from .forms import CreateCorpusForm
from ..decorators import admin_required
import hashlib
import os


@main.route('/', methods=['GET', 'POST'])
@login_required
def dashboard():
    create_corpus_form = CreateCorpusForm()

    if create_corpus_form.validate_on_submit():
        app = current_app._get_current_object()
        id = hashlib.md5(
            (current_user.username + '_' + datetime.now().isoformat()).encode()
        ).hexdigest()
        corpus = {'description': create_corpus_form.description.data,
                  'id': id,
                  'creator': current_user.id,
                  'title': create_corpus_form.title.data
                  }
        dir = os.path.join(app.config['OPAQUE_FILES'], 'corpora', id)

        try:
            os.makedirs(dir)
        except OSError:
            flash('OSError!')
        else:
            for file in create_corpus_form.files.data:
                file.save(os.path.join(dir, file.filename))
            flash('Corpus created!')
        return redirect(url_for('main.dashboard'))

    return render_template(
        'main/dashboard.html.j2',
        title='Dashboard',
        create_corpus_form=create_corpus_form
    )


@main.route('/about')
def about():
    return render_template('main/about.html.j2', title='About')


@main.route('/admin', methods=['GET', 'POST'])
@login_required
@admin_required
def for_admins_only():
    """
    View for admin page only accesible by admins.
    """
    users = User.query.order_by(User.username).all()
    items = [AdminUserItem(u.username, u.email, u.role_id, u.confirmed) for u in users]
    table = AdminUserTable(items)
    return render_template('main/admin.html.j2', title='Administration tools',
                           table=table.__html__())
